/*
   Situare - A location system for Facebook
   Copyright (C) 2010  Ixonos Plc. Authors:

       Jussi Laitinen - jussi.laitinen@ixonos.com

   Situare is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   version 2 as published by the Free Software Foundation.

   Situare is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with Situare; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
   USA.
*/

#include <QDebug>
#include <QTimer>

#include "networkhandler.h"
#include "networkhandlerprivatestub.h"


NetworkHandlerPrivate::NetworkHandlerPrivate(QObject *parent)
    : QObject(parent)
{
    qDebug() << __PRETTY_FUNCTION__;

    m_parent = static_cast<NetworkHandler*>(parent);
    QTimer::singleShot(0, this, SLOT(connected()));
}

void NetworkHandlerPrivate::connect()
{
    qDebug() << __PRETTY_FUNCTION__;
}

void NetworkHandlerPrivate::connected()
{
    qDebug() << __PRETTY_FUNCTION__;

    emit m_parent->connected();
}

void NetworkHandlerPrivate::disconnect()
{
    qDebug() << __PRETTY_FUNCTION__;
}

bool NetworkHandlerPrivate::isConnected()
{
    qDebug() << __PRETTY_FUNCTION__;

    return true;
}

void NetworkHandlerPrivate::state()
{
    qDebug() << __PRETTY_FUNCTION__;
}
